public inbox for passt-dev@passt.top
 help / color / mirror / code / Atom feed
From: David Gibson <david@gibson.dropbear.id.au>
To: Stefano Brivio <sbrivio@redhat.com>, passt-dev@passt.top
Cc: David Gibson <david@gibson.dropbear.id.au>
Subject: [PATCH 2/3] tcp: Simplify away tcp_port_rebind()
Date: Wed, 15 Nov 2023 16:25:33 +1100	[thread overview]
Message-ID: <20231115052534.1826261-3-david@gibson.dropbear.id.au> (raw)
In-Reply-To: <20231115052534.1826261-1-david@gibson.dropbear.id.au>

tcp_port_rebind() is desgined to be called from NS_CALL() and has two
disjoint cases: one where it enters the namespace (outbound forwards) and
one where it doesn't (inbound forwards).

We only actually need the NS_CALL() framing for the outbound case, for
inbound we can just call tcp_port_do_rebind() directly.  So simplify
tcp_port_rebind() to tcp_port_rebind_outbound(), allowing us to eliminate
an awkward parameters structure.

With that done we can safely rename tcp_port_do_rebind() to
tcp_port_rebind() for brevity.

Signed-off-by: David Gibson <david@gibson.dropbear.id.au>
---
 tcp.c | 41 ++++++++++++-----------------------------
 1 file changed, 12 insertions(+), 29 deletions(-)

diff --git a/tcp.c b/tcp.c
index 6bc040c..b933042 100644
--- a/tcp.c
+++ b/tcp.c
@@ -3156,13 +3156,13 @@ int tcp_init(struct ctx *c)
 }
 
 /**
- * tcp_port_do_rebind() - Rebind ports to match forward maps
+ * tcp_port_rebind() - Rebind ports to match forward maps
  * @c:		Execution context
  * @outbound:	True to remap outbound forwards, otherwise inbound
  *
  * Must be called in namespace context if @outbound is true.
  */
-static void tcp_port_do_rebind(struct ctx *c, bool outbound)
+static void tcp_port_rebind(struct ctx *c, bool outbound)
 {
 	const uint8_t *fmap = outbound ? c->tcp.fwd_out.map : c->tcp.fwd_in.map;
 	const uint8_t *rmap = outbound ? c->tcp.fwd_in.map : c->tcp.fwd_out.map;
@@ -3199,32 +3199,19 @@ static void tcp_port_do_rebind(struct ctx *c, bool outbound)
 }
 
 /**
- * struct tcp_port_rebind_arg - Arguments for tcp_port_rebind()
- * @c:			Execution context
- * @bind_in_ns:		Rebind ports in namespace, not in init
- */
-struct tcp_port_rebind_arg {
-	struct ctx *c;
-	int bind_in_ns;
-};
-
-/**
- * tcp_port_rebind() - Rebind ports in namespace or init
- * @arg:		See struct tcp_port_rebind_arg
+ * tcp_port_rebind_outbound() - Rebind ports in namespace
+ * @arg:	Execution context
+ *
+ * Called with NS_CALL()
  *
  * Return: 0
  */
-static int tcp_port_rebind(void *arg)
+static int tcp_port_rebind_outbound(void *arg)
 {
-	struct tcp_port_rebind_arg *a = (struct tcp_port_rebind_arg *)arg;
-
-	if (a->bind_in_ns) {
-		ns_enter(a->c);
+	struct ctx *c = (struct ctx *)arg;
 
-		tcp_port_do_rebind(a->c, true);
-	} else {
-		tcp_port_do_rebind(a->c, false);
-	}
+	ns_enter(c);
+	tcp_port_rebind(c, true);
 
 	return 0;
 }
@@ -3241,18 +3228,14 @@ void tcp_timer(struct ctx *c, const struct timespec *ts)
 	(void)ts;
 
 	if (c->mode == MODE_PASTA) {
-		struct tcp_port_rebind_arg rebind_arg = { c, 0 };
-
 		if (c->tcp.fwd_out.mode == FWD_AUTO) {
 			port_fwd_scan_tcp(&c->tcp.fwd_out, &c->tcp.fwd_in);
-			rebind_arg.bind_in_ns = 1;
-			NS_CALL(tcp_port_rebind, &rebind_arg);
+			NS_CALL(tcp_port_rebind_outbound, c);
 		}
 
 		if (c->tcp.fwd_in.mode == FWD_AUTO) {
 			port_fwd_scan_tcp(&c->tcp.fwd_in, &c->tcp.fwd_out);
-			rebind_arg.bind_in_ns = 0;
-			tcp_port_rebind(&rebind_arg);
+			tcp_port_rebind(c, false);
 		}
 	}
 
-- 
@@ -3156,13 +3156,13 @@ int tcp_init(struct ctx *c)
 }
 
 /**
- * tcp_port_do_rebind() - Rebind ports to match forward maps
+ * tcp_port_rebind() - Rebind ports to match forward maps
  * @c:		Execution context
  * @outbound:	True to remap outbound forwards, otherwise inbound
  *
  * Must be called in namespace context if @outbound is true.
  */
-static void tcp_port_do_rebind(struct ctx *c, bool outbound)
+static void tcp_port_rebind(struct ctx *c, bool outbound)
 {
 	const uint8_t *fmap = outbound ? c->tcp.fwd_out.map : c->tcp.fwd_in.map;
 	const uint8_t *rmap = outbound ? c->tcp.fwd_in.map : c->tcp.fwd_out.map;
@@ -3199,32 +3199,19 @@ static void tcp_port_do_rebind(struct ctx *c, bool outbound)
 }
 
 /**
- * struct tcp_port_rebind_arg - Arguments for tcp_port_rebind()
- * @c:			Execution context
- * @bind_in_ns:		Rebind ports in namespace, not in init
- */
-struct tcp_port_rebind_arg {
-	struct ctx *c;
-	int bind_in_ns;
-};
-
-/**
- * tcp_port_rebind() - Rebind ports in namespace or init
- * @arg:		See struct tcp_port_rebind_arg
+ * tcp_port_rebind_outbound() - Rebind ports in namespace
+ * @arg:	Execution context
+ *
+ * Called with NS_CALL()
  *
  * Return: 0
  */
-static int tcp_port_rebind(void *arg)
+static int tcp_port_rebind_outbound(void *arg)
 {
-	struct tcp_port_rebind_arg *a = (struct tcp_port_rebind_arg *)arg;
-
-	if (a->bind_in_ns) {
-		ns_enter(a->c);
+	struct ctx *c = (struct ctx *)arg;
 
-		tcp_port_do_rebind(a->c, true);
-	} else {
-		tcp_port_do_rebind(a->c, false);
-	}
+	ns_enter(c);
+	tcp_port_rebind(c, true);
 
 	return 0;
 }
@@ -3241,18 +3228,14 @@ void tcp_timer(struct ctx *c, const struct timespec *ts)
 	(void)ts;
 
 	if (c->mode == MODE_PASTA) {
-		struct tcp_port_rebind_arg rebind_arg = { c, 0 };
-
 		if (c->tcp.fwd_out.mode == FWD_AUTO) {
 			port_fwd_scan_tcp(&c->tcp.fwd_out, &c->tcp.fwd_in);
-			rebind_arg.bind_in_ns = 1;
-			NS_CALL(tcp_port_rebind, &rebind_arg);
+			NS_CALL(tcp_port_rebind_outbound, c);
 		}
 
 		if (c->tcp.fwd_in.mode == FWD_AUTO) {
 			port_fwd_scan_tcp(&c->tcp.fwd_in, &c->tcp.fwd_out);
-			rebind_arg.bind_in_ns = 0;
-			tcp_port_rebind(&rebind_arg);
+			tcp_port_rebind(c, false);
 		}
 	}
 
-- 
2.41.0


  parent reply	other threads:[~2023-11-15  5:25 UTC|newest]

Thread overview: 5+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-11-15  5:25 [PATCH 0/3] pasta: Implement runtime auto-forwarding for UDP David Gibson
2023-11-15  5:25 ` [PATCH 1/3] tcp: Use common helper for rebinding inbound and outbound ports David Gibson
2023-11-15  5:25 ` David Gibson [this message]
2023-11-15  5:25 ` [PATCH 3/3] udp,pasta: Periodically scan for ports to automatically forward David Gibson
2023-11-19 20:10 ` [PATCH 0/3] pasta: Implement runtime auto-forwarding for UDP Stefano Brivio

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20231115052534.1826261-3-david@gibson.dropbear.id.au \
    --to=david@gibson.dropbear.id.au \
    --cc=passt-dev@passt.top \
    --cc=sbrivio@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://passt.top/passt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for IMAP folder(s).